package OAuth::Lite2;

use strict;
use warnings;

our $VERSION = '0.04';

1;
__END__

=head1 NAME

OAuth::Lite2 - OAuth 2.0 Library

=head1 DESCRIPTION

OAuth 2.0 Library

The maintainer of this CPAN module was transferred to ritou by lyokato.
Main repository is https://github.com/ritou/p5-oauth-lite2.

=head1 SEE ALSO

Client

L<OAuth::Lite2::Client::WebServer>
L<OAuth::Lite2::Client::UsernameAndPassword>

Server

L<OAuth::Lite2::Server::Endpoint::Token>
L<Plack::Middleware::Auth::OAuth2::ProtectedResource>

=head1 AUTHOR

Ryo Ito, E<lt>ritou.06@gmail.comE<gt>
Lyo Kato, E<lt>lyo.kato@gmail.comE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2010 by Lyo Kato

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.8 or,
at your option, any later version of Perl 5 you may have available.

=cut
